@@ -73,8 +73,5 @@ public class OXMFErrorStrings implements LocalizableStrings{
     
     // Could not fetch site at %1$s. Please check the spelling or whether you can reach the site in your browser.
     public static final String ERROR_LOADING_SUBSCRIPTION = "Could not fetch site at %1$s. Please check the spelling or whether you can reach the site in your browser.";
-
-    // The string cannot be parsed to a valid URL.
-    public static final String INVALID_URL = "The string cannot be parsed to a valid URL.";
         
 }
