@@ -51,7 +51,6 @@ package com.openexchange.subscribe.microformats.transformers;
 import java.io.BufferedInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
-import java.io.InputStream;
 import java.net.MalformedURLException;
 import java.net.URL;
 import java.net.URLConnection;
@@ -435,12 +434,6 @@ public class MapToContactObjectTransformer implements MapToObjectTransformer{
             LOG.warn(new StringBuilder(32 + uri.length()).append("Image  URI could not be loaded: ").append(uri).toString(), e);
         }
         if (bytes != null) {
-            final String imimeType = com.openexchange.java.ImageTypeDetector.getMimeType(bytes);
-            if (!imimeType.toLowerCase().startsWith("image/") || com.openexchange.java.HTMLDetector.containsHTMLTags(bytes)) {
-                throw new IllegalStateException("Not a valid image file");
-            } else if (!isValidImage(new com.openexchange.java.UnsynchronizedByteArrayInputStream(bytes))) {
-                throw new IllegalStateException("Not an image file");
-            }
             contactContainer.setImage1(bytes);
             if (mimeType == null) {
                 mimeType = ImageTypeDetector.getMimeType(bytes);
@@ -451,16 +444,7 @@ public class MapToContactObjectTransformer implements MapToObjectTransformer{
             contactContainer.setImageContentType(mimeType);
         }
     }
-
-	/** Checks for a valid image */
-    private static boolean isValidImage(final InputStream data) {
-        java.awt.image.BufferedImage bimg = null;
-        try {
-            bimg = javax.imageio.ImageIO.read(data);
-        } catch (final Exception e) {
-            return false;
-        }
-        return (bimg != null && bimg.getHeight() > 0 && bimg.getWidth() > 0);
-    }	
+	
+	
 
 }
